==> tiles_2.0.6.orig.tar.gz: tiles-2.0.6/src/tiles-api/src/main/java/org/apache/tiles/TilesException.java <==
/*
 * $Id: TilesException.java 527536 2007-04-11 15:44:51Z apetrelli $
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tiles;


/**
 * Root class for all Tiles-exceptions.
 *
 * @version $Rev: 527536 $ $Date: 2007-04-11 17:44:51 +0200 (Wed, 11 Apr 2007) $
 */
public class TilesException extends Exception {

    /**
     * Constructor.
     */
    public TilesException() {
        super();
    }

    /**
     * Constructor.
     *
     * @param message The error or warning message.
     */
    public TilesException(String message) {
        super(message);
    }


    /**
     * Create a new <code>TilesException</code> wrapping an existing exception.
     * <p/>
     * <p>The existing exception will be embedded in the new
     * one, and its message will become the default message for
     * the TilesException.</p>
     *
     * @param e The exception to be wrapped.
     */
    public TilesException(Exception e) {
        super(e);
    }


    /**
     * Create a new <code>TilesException</code> from an existing exception.
     * <p/>
     * <p>The existing exception will be embedded in the new
     * one, but the new exception will have its own message.</p>
     *
     * @param message The detail message.
     * @param e       The exception to be wrapped.
     */
    public TilesException(String message, Exception e) {
        super(message, e);
    }
}

==> tiles_2.2.2.orig.tar.gz: tiles-2.2.2/src/tiles-api/src/main/java/org/apache/tiles/TilesException.java <==
/*
 * $Id: TilesException.java 819630 2009-09-28 16:18:57Z apetrelli $
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tiles;


/**
 * Root class for all Tiles-exceptions.
 *
 * @version $Rev: 819630 $ $Date: 2009-09-28 18:18:57 +0200 (lun, 28 set 2009) $
 */
public class TilesException extends RuntimeException {

    /**
     * Constructor.
     */
    public TilesException() {
        super();
    }

    /**
     * Constructor.
     *
     * @param message The error or warning message.
     */
    public TilesException(String message) {
        super(message);
    }


    /**
     * Create a new <code>TilesException</code> wrapping an existing exception.
     * <p/>
     * <p>The existing exception will be embedded in the new
     * one, and its message will become the default message for
     * the TilesException.</p>
     *
     * @param e The cause to be wrapped.
     */
    public TilesException(Throwable e) {
        super(e);
    }


    /**
     * Create a new <code>TilesException</code> from an existing exception.
     * <p/>
     * <p>The existing exception will be embedded in the new
     * one, but the new exception will have its own message.</p>
     *
     * @param message The detail message.
     * @param e       The cause to be wrapped.
     */
    public TilesException(String message, Throwable e) {
        super(message, e);
    }
}
